Start Romagna
Description: Start, la nuova grande realtà del trasporto pubblico in Romagna.

- # Nuovo Carnet 10 corse

  Il Carnet 10 corse è valido per 10 viaggi più i trasbordi ed è utilizzabile da più persone contemporaneamente

  SCOPRI TUTTO

- # DropTicket

  Il biglietto del bus che si acquista con lo smartphone e va convalidato entro 24 ore.

  Scopri tutto

- # WhatsApp Start Romagna

  Informazioni su linee, orari, percorsi e domande relative al trasporto pubblico locale in tempo reale.

  Scopri tutto

Ravenna

### Punta Marina Terme, sabato 5 e domenica 6 dicembre

Fino al 09/12/2015 Bacino: Ravenna Linee: 70 LIT - 75 LIT - 80 LIT

### Ravenna, Linea 1, servizio straordinario Natale 2015

Fino al 20/12/2015 Bacino: Ravenna Linee: TUTTE

### Marina di Ravenna, dal 12 ottobre anticipo corsa Linea 70

Fino al 06/06/2016 Bacino: Ravenna Linee: 70 LIT

### Ravenna, dal 12 ottobre modifiche corse Linea 40

Fino al 06/06/2016 Bacino: Ravenna Linee: 40 LIT

### Ravenna, dal 12 ottobre anticipo corsa Linea 4

Fino al 06/06/2016 Bacino: Ravenna Linee: 4 URB
Leggi tutte le info bus e news di Ravenna →
Forlì-Cesena

### Modifica di percorso linea 4 di Cesena per mercatino dei ricordi

Fino al 06/12/2015 Bacino: Forlì-Cesena Linee: 4 CE

### Cesena, Potenziamento mercati straordinari 6 - 8 - 13 -20 dicembre

Fino al 21/12/2015 Bacino: Forlì-Cesena Linee: 4 CE

### Cesena, lunedì 7 dicembre, servizio con corse a validità non scolastica

Fino al 07/12/2015 Bacino: Forlì-Cesena Linee: Cesena

### Forlì, lunedì 7 dicembre, servizio con corse a validità non scolastica

Fino al 07/12/2015 Bacino: Forlì-Cesena Linee: Forlì - Collegamenti scolastici FO

### Forlì, 7 dicembre ponte dell’Immacolata, Linee S1, S2, S4, S8

Fino al 07/12/2015 Bacino: Forlì-Cesena Linee: S8 FO - S4 FO - S2 FO - S1 FO
Leggi tutte le info bus e news di Forlì-Cesena →
Rimini

### Verucchio, 6, 13 e 20 dicembre, “Fiera di Natale”

Fino al 20/12/2015 Bacino: Rimini Linee: 160

### Sogliano al Rubicone, “Sagra del formaggio di Fossa”, Linea 169

Fino al 06/12/2015 Bacino: Rimini Linee: 169

### Rimini, modifiche servizi dal 14 ottobre

Fino al 06/06/2016 Bacino: Rimini Linee: TUTTE

### Rimini, da mercoledì 14 ottobre 2015 nuova Navetta Grandi Mercati (GM)

Fino al 06/06/2016 Bacino: Rimini Linee: TUTTE

### Santarcangelo, dal 15 ottobre modifica corsa Linea 166

Fino al 06/06/2016 Bacino: Rimini Linee: 166
Leggi tutte le info bus e news di Rimini →

### Calendario Rimini Fiera

04/11/2015

Calendario degli Eventi Fieristici 2015-2016 con integrazioni ai servizi di trasporto ...

### Progetto OK BUS - Viaggiare in regola: intensificata l’attività di controllo a Forlì , Cesena e Ravenna

03/11/2015

Start Romagna, come già preannunciato, avvierà in questi giorni una nuova iniziativa ...

### Carnet 10 corse, il nuovo biglietto multicorse magnetico

30/10/2015

Più semplice da usare, per viaggiare anche in compagnia. Il nuovo biglietto multicors...

### Bacino di Forlì-Cesena, nuove fermate abilitate al trasporto di persone diversamente abili

13/10/2015

Da martedì 13 ottobre 2015 Vengono autorizzate al trasporto di persone diversamente abi...

Leggi tutte le info bus e news di Ravenna →
Leggi tutte le info bus e news di Forlì-Cesena →
Leggi tutte le info bus e news di Rimini →

## Crea il tuo percorso

### Google Transit

Un facile strumento per ottenere informazioni sui servizi di trasporto pubblico locale disponibili sul territorio, con percorsi e fermate visualizzate sulle mappe di Google.
Segui le istruzioni

## Vuoi rinnovare il tuo abbonamento online

### Senza file allo sportello ?

Rinnova online il tuo abbonamento
Premi qui

## Devi andare da qualche parte?

### Guarda gli orari e i percorsi

Consulta tutti i libretti orari per scegliere la linea e il percorso del trasporto pubblico in Romagna.
Consulta gli orari

## Area Riservata Start&You

Username o Email
Password
Ricordami Password dimenticata?

Non hai ancora un account?
Scopri i vantaggi del mondo Start

Registrati
Adesso